home | help
ISCSICTL(8)		     System Manager's Manual		     ISCSICTL(8)

NAME
     iscsictl -- iSCSI initiator management utility

SYNOPSIS
     iscsictl -A -p portal -t target [-u user -s secret] [-w timeout] [-r]
	      [-e on|off]
     iscsictl -A -d discovery-host [-u user -s secret] [-r] [-e on|off]
     iscsictl -A -a [-c path]
     iscsictl -A -n nickname [-c path]
     iscsictl -M -i session-id [-p portal] [-t target] [-u user] [-s secret]
	      [-e on|off]
     iscsictl -M -i session-id [-n nickname [-c path]]
     iscsictl -R [-p portal] [-t target]
     iscsictl -R -a
     iscsictl -R -n nickname [-c path]
     iscsictl -L [-v] [-w timeout]

DESCRIPTION
     The iscsictl utility is used to configure the iSCSI initiator.

     The following options are available:

     --libxo		Generate output via libxo(3) in a selection of different
			human  and  machine readable formats.  See xo_options(7)
			for details on command line arguments.

     -A 		Add session.

     -M 		Modify session.

     -R 		Remove session.

     -L 		List sessions.

     -a 		When adding, add all sessions defined in the  configura-
			tion  file.   When removing, remove all currently estab-
			lished sessions.

     -c path		Path  to  the  configuration  file.   The   default   is
			/etc/iscsi.conf.

     -d discovery-host	Target host name or address used for SendTargets discov-
			ery.   When used, it will add a temporary discovery ses-
			sion.  After discovery is done, sessions will  be  added
			for  each discovered target, and the temporary discovery
			session will be removed.

     -e on|off		Enable or disable the session.	This is ignored for dis-
			covery sessions, but gets passed down to normal sessions
			they add.

     -i session-id	Session ID, as displayed by iscsictl -v.

     -n nickname	The nickname of a session defined in  the  configuration
			file.

     -p portal		Target	portal -- host name or address -- for statically
			defined targets.

     -r 		Use iSER (iSCSI over RDMA) instead of plain  iSCSI  over
			TCP/IP.

     -s secret		CHAP secret.

     -t target		Target name.

     -u user		CHAP login.

     -v 		Verbose mode.

     -w timeout 	Instead  of  returning	immediately,  wait up to timeout
			seconds until all configured sessions  are  successfully
			established.

     Certain  parameters  are  necessary when adding a session.  One can specify
     these either via command line (using the -t, -p, -u, and  -s  options),  or
     configuration  file (using the -a or -n options).	Some functionality - for
     example mutual CHAP - is available only via configuration file.

     Since connecting to the target is performed in  background,  non-zero  exit
     status  does  not	mean that the session was successfully established.  Use
     either iscsictl -L to check the connection status, or the -w flag	to  wait
     for session establishment.

     Note  that in order for the iSCSI initiator to be able to connect to a tar-
     get, the iscsid(8) daemon must be running.

FILES
     /etc/iscsi.conf  iSCSI initiator configuration file.

EXIT STATUS
     The iscsictl utility exits 0 on success, and >0 if an error occurs.

EXAMPLES
     Attach to target iqn.2012-06.com.example:target0, served by 192.168.1.1:
	   iscsictl -A -t iqn.2012-06.com.example:target0 -p 192.168.1.1

     Perform discovery on 192.168.1.1, and add disabled sessions for  each  dis-
     covered target; use -M -e on to connect them:
	   iscsictl -A -d 192.168.1.1 -e off

     Disconnect all iSCSI sessions:
	   iscsictl -Ra

SEE ALSO
     libxo(3), xo_options(7), iscsi(4), iscsi.conf(5), iscsid(8)

HISTORY
     The iscsictl command appeared in FreeBSD 10.0.

AUTHORS
     The   iscsictl   utility	was   developed   by   Edward  Tomasz  Napierala
     <trasz@FreeBSD.org> under sponsorship from the FreeBSD Foundation.

FreeBSD 15.1			  July 16, 2025 		     ISCSICTL(8)

home | help